//
//  FancyViewController.m
//  Library
//
//  Created by John Ray on 2/9/12.
//  Copyright (c) 2012 Poisontooth Enterprises. All rights reserved.
//

#import "FancyViewController.h"

@implementation FancyViewController
@synthesize fetchedResults;

- (void)setupFetchedResults {
    
    // Setup the request for all books
    AppDelegate *appDelegate = (AppDelegate *)[[UIApplication sharedApplication] delegate];
    NSManagedObjectContext *objectContext = [appDelegate managedObjectContext];
    NSFetchRequest *fetchRequest = [[NSFetchRequest alloc] init];
    NSEntityDescription *booksEntity = [NSEntityDescription entityForName:@"Books" 
                                                   inManagedObjectContext:objectContext];
    [fetchRequest setEntity:booksEntity];
    
    // Sort by publication Date
    NSSortDescriptor *booksSort = [[NSSortDescriptor alloc] 
                                   initWithKey:@"publicationYear" ascending:YES];
    [fetchRequest setSortDescriptors:[NSArray arrayWithObject:booksSort]];

    // Set the fetched results controller property
    NSFetchedResultsController *fetchedResultsController = 
    [[NSFetchedResultsController alloc] initWithFetchRequest:fetchRequest 
                    managedObjectContext:objectContext sectionNameKeyPath:nil 
                    cacheName:@"Root"];
    fetchedResultsController.delegate=self;
    self.fetchedResults = fetchedResultsController;
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView
{
}
*/

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    id <NSFetchedResultsSectionInfo> sectionInfo = 
            [[fetchedResults sections] objectAtIndex:section];
    return [sectionInfo numberOfObjects];
}



- (UITableViewCell *)tableView:(UITableView *)tableView 
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
	UITableViewCell *cell = [tableView 
                             dequeueReusableCellWithIdentifier:@"bookCell"];
    
    
    Books *book = [fetchedResults objectAtIndexPath:indexPath];
    
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:@"yyyy"];
    NSString *pubYear;
    pubYear=[dateFormatter stringFromDate:book.publicationYear];
    
    cell.textLabel.text = [[NSString alloc] initWithFormat:@"%@ (%@)",book.title,pubYear];


    cell.detailTextLabel.text = [[NSString alloc] initWithFormat:@"%@, %@ (%@)",
                                 book.authorInfo.lastName,
                                 book.authorInfo.firstName,
                                 book.authorInfo.email];
    
    return cell;
}


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    NSError *error;
    [self setupFetchedResults];
	[fetchedResults performFetch:&error];
    [super viewDidLoad];
}


- (void)viewDidUnload
{
    [self setFetchedResults:nil];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

- (IBAction)dismissView:(id)sender {
    [self dismissModalViewControllerAnimated:YES];
}
@end
